WebDataChannel class

Implemented types

Constructors

WebDataChannel(RTCDataChannel _dc)

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
no setteroverride
onMessage → Stream
Data stream
no setteroverride
onState → Stream<DataChannelState>
State stream
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
Close channel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(dynamic data) → Future<void>
Send data
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited